<?php

declare(strict_types=1);

namespace Drupal\flysystem_local\Plugin\FlysystemAdapter;

use League\Flysystem\Local\LocalFilesystemAdapter;
use League\Flysystem\UnixVisibility\PortableVisibilityConverter;

/**
 * Local Adapter factory class.
 */
class LocalAdapterUtility {

  /**
   * Configures the designated adapter.
   *
   * @param array $sub_adapter_config
   *   The sub adapter config item for this adapter config.
   *
   * @return array
   *   Array containing configured adapter and configuration options array.
   */
  public static function create($sub_adapter_config) {
    $options = [];
    $visibilityArray = [
      'file' => [
        'public' => (int) $sub_adapter_config['permissions']['file']['public'],
        'private' => (int) $sub_adapter_config['permissions']['file']['private'],
      ],
      'dir' => [
        'public' => (int) $sub_adapter_config['permissions']['dir']['public'],
        'private' => (int) $sub_adapter_config['permissions']['dir']['private'],
      ],
    ];
    // Set to converter, or set to NULL if not supported.
    // @see https://flysystem.thephpleague.com/docs/ for information on configuring adapters.
    $visibility = PortableVisibilityConverter::fromArray($visibilityArray);
    $link_handling = strlen($sub_adapter_config['link_handling']) == 0 ? LocalFilesystemAdapter::DISALLOW_LINKS : LocalFilesystemAdapter::SKIP_LINKS;
    $adapter = new LocalFilesystemAdapter(
      $sub_adapter_config['root_directory'],
      $visibility,
      (int) $sub_adapter_config['write_flags'],
      $link_handling,
    );
    $options['visibility'] = $visibility;
    return ['adapter' => $adapter, 'options' => $options];
  }

}
