<?php

namespace Drupal\flysystem\Flysystem\Adapter;

use League\Flysystem\Config;
use League\Flysystem\FilesystemAdapter;
use League\Flysystem\FileAttributes;
use League\Flysystem\Visibility;

/**
 * An adapter used when a plugin is missing. It fails at everything.
 */
class MissingAdapter implements FilesystemAdapter {

  /**
   * {@inheritdoc}
   */
  public function fileExists($path): bool {
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function directoryExists(string $path): bool {
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function copy($path, $newPath, Config $config = new Config([])): void {}

  /**
   * {@inheritdoc}
   */
  public function createDirectory($dirname, Config $config = new Config([])): void {}

  /**
   * {@inheritdoc}
   */
  public function delete($path): void {}

  /**
   * {@inheritdoc}
   */
  public function deleteDirectory($dirname): void {}

  /**
   * {@inheritdoc}
   */
  public function listContents($directory = '', $recursive = FALSE): iterable {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function mimeType($path): FileAttributes {
    return new FileAttributes($path, NULL, NULL, NULL, 'plain/text');
  }

  /**
   * {@inheritdoc}
   */
  public function fileSize($path): FileAttributes {
    return new FileAttributes($path, 1234, NULL, NULL, NULL);
  }

  /**
   * {@inheritdoc}
   */
  public function lastModified($path): FileAttributes {
    return new FileAttributes($path, NULL, NULL, $now = time(), NULL);
  }

  /**
   * {@inheritdoc}
   */
  public function visibility($path): FileAttributes {
    return new FileAttributes($path, NULL, Visibility::PRIVATE, NULL, NULL);
  }

  /**
   * {@inheritdoc}
   */
  public function setVisibility($path, $visibility): void {}

  /**
   * {@inheritdoc}
   */
  public function read($path): string {
    return '';
  }

  /**
   * {@inheritdoc}
   */
  public function readStream($path) {
    return '';
  }

  /**
   * {@inheritdoc}
   */
  public function move($path, $newPath, Config $config = new Config([])): void {}

  /**
   * {@inheritdoc}
   */
  public function write($path, $contents, Config $config = new Config([])): void {}

  /**
   * {@inheritdoc}
   */
  public function writeStream($path, $resource, Config $config = new Config([])): void {}

}
