<?php

declare(strict_types=1);

namespace Drupal\flysystem;

use Drupal\Component\Plugin\ConfigurableInterface;
use Drupal\Component\Plugin\DependentPluginInterface;
use Drupal\Component\Plugin\DerivativeInspectionInterface;
use Drupal\Component\Plugin\PluginInspectionInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;

/**
 * Interface for flysystem_adapter plugins.
 */
interface FlysystemAdapterInterface extends PluginInspectionInterface, DerivativeInspectionInterface, ConfigurableInterface, DependentPluginInterface, ContainerFactoryPluginInterface {

  /**
   * Returns the translated plugin label.
   */
  public function label(): string;

  /**
   * Retrieves plugin ID of the Flysystem (sub)adapter of this config entity.
   *
   * @return string
   *   The plugin ID of the subadapter.
   */
  public function getSubAdapterId();

  /**
   * Return the configuration of this config entity's Flysystem (sub)adapter.
   *
   * @return array
   *   An associative array with the subadapter configuration.
   */
  public function getSubAdapterConfig();

  /**
   * Builds the Sub Configuration Form components for Form array.
   *
   * @param array $form
   *   Form array.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   Drupal Form State object.
   * @param \Drupal\flysystem\FlysystemAdapterConfigInterface $flysystem_adapter_config
   *   Flysystem Adapter Configuration entity.
   *
   * @return array
   *   Form array with subform items added.
   */
  public function buildSubConfigurationForm(array $form, FormStateInterface $form_state, FlysystemAdapterConfigInterface $flysystem_adapter_config);

  /**
   * Get Default file/directory permissions.
   *
   * Return array
   *   Default permissions stored in $defaultPermissions property.
   */
  public function getDefaultPermissions();

}
