<?php

declare(strict_types=1);

namespace Drupal\flysystem;

use Drupal\Component\Plugin\ConfigurableInterface;
use Drupal\Component\Plugin\DependentPluginInterface;
use Drupal\Component\Plugin\DerivativeInspectionInterface;
use Drupal\Component\Plugin\PluginInspectionInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Plugin\PluginFormInterface;

/**
 * Interface for flysystem_adapter plugins.
 */
interface FlysystemSubAdapterInterface extends PluginFormInterface, PluginInspectionInterface, DerivativeInspectionInterface, ConfigurableInterface, DependentPluginInterface, ContainerFactoryPluginInterface {

  /**
   * Returns the translated plugin label.
   */
  public function label(): string;

  /**
   * Returns the subAdapter description.
   *
   * @return string
   *   SubAdapter description.
   */
  public function getDescription();

  /**
   * Builds the Sub Configuration Form components for Form array.
   *
   * This method description is the same as that declared in
   * \Drupal\flysystem\FlysystemAdapterInterface, but is also included here for
   * clarity and documentation of what needs to be implemented in a
   * sub adapter plugin entity type.
   *
   * @param array $form
   *   Form array.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   Drupal Form State object.
   * @param \Drupal\flysystem\FlysystemAdapterConfigInterface $flysystem_adapter_config
   *   Flysystem Adapter Configuration entity.
   *
   * @return array
   *   Form array with subform items added.
   */
  public function buildSubConfigurationForm(array &$form, FormStateInterface $form_state, FlysystemAdapterConfigInterface $flysystem_adapter_config);

  /**
   * Get Default file/directory permissions.
   *
   * Return array
   *   Default permissions stored in $defaultPermissions property.
   */
  public function getDefaultPermissions();

}
